# Table of Contents

- [ai-governance-and-adoption-assess-potential](<./ai-governance-and-adoption-assess-potential.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 2: Assess AI Potential and Usage](<./Step-2-Assess-AI-Potential-and-Usage.md>)
  - [AI Potential of Business Capabilities](<./Step-2-Assess-AI-Potential-and-Usage/AI-Potential-of-Business-Capabilities.md>)
  - [AI Potential and Usage of Applications](<./Step-2-Assess-AI-Potential-and-Usage/AI-Potential-and-Usage-of-Applications.md>)
  - [Business Value and Usage of AI Agents](<./Step-2-Assess-AI-Potential-and-Usage/Business-Value-and-Usage-of-AI-Agents.md>)
